Test coverage report: subscribe.tests.test_app.models

# subscribe.tests.test_app.models: 5 total statements, 100.0% covered

Generated: Sat 2013-04-06 17:51 SGT

Source file: /Users/martin/Repos/django-subscribe/subscribe/tests/test_app/models.py

Stats: 2 executed, 0 missed, 3 excluded, 4 ignored

1. `"""Dummy models for tests of the ``subscription`` app."""`
2. `from django.db import models`
3. ``
4. ``
5. `class DummyModel(models.Model):`
6. `name = models.CharField(max_length=256)`
7. ``
8. `def get_absolute_url(self):`
9. `return '/'`